TopicSubscriber

Struct TopicSubscriber 

pub struct TopicSubscriber<'a, I: Instance + ?Sized> { /* private fields */ }

Implementations

Source

impl<I: Instance + ?Sized> TopicSubscriber<'_, I>

pub fn try_read_update_queue_raw(&self) -> Option<Vec<RawValue>>

Returns all of the new topic values since the last read in their raw form (timestamps included).

If there have been no new updates, None is returned.

pub fn try_read_update_queue(&self) -> Option<Vec<Value>>

pub fn update_queue_raw(&self) -> TopicSubscriberReadQueueRawFuture<'_, I>

pub async fn update_queue(&self) -> Vec<Value>

pub async fn value(&self) -> Value

pub async fn value_bool(&self) -> Option<bool>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_i64(&self) -> Option<i64>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_f32(&self) -> Option<f32>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_f64(&self) -> Option<f64>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_string(&self) -> Option<String>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_raw(&self) -> Option<Vec<u8>>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_bool_array(&self) -> Option<Vec<bool>>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_f64_array(&self) -> Option<Vec<f64>>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_f32_array(&self) -> Option<Vec<f32>>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_i64_array(&self) -> Option<Vec<i64>>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub async fn value_string_array(&self) -> Option<Vec<String>>

Returns the value of this topic if it is of the specified type. Returns None if the type of the entry is not of the specified type.

pub unsafe fn handle(&self) -> NT_Subscriber

Safety

Caller must ensure that the returned handle is only used while the topic and subscriber is valid.